==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/lv.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Pārvaldīt Lightbox gallary parametri");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "pārvaldīt galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Pilna izmēra attēlu platums");
define('MANAGE_GALLERY_FULL_HEIGHT', "Pilnā izmērā Augstums");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image platums");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image augstums");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Saglabāt Thumb malu attiecību");
define('MANAGE_GALLERY_SHOW_TITLES', "Rādīt sadaļu");
define('MANAGE_GALLERY_DISABLE_SORT', "Atslēgt Kārtot");
define('MANAGE_GALLERY_DELETE_IMAGE', "dzēst attēlu");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Saglabājiet kārtošanas secību");
define('MANAGE_GALLERY_PUBLISH_MSG', "Nospiediet &#39;Atjaunināt&#39; publicēt <br /> Jūsu augšupielādēto attēlu.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Visi attēli ir mainīti un iestatījumi ir saglabāti.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Radās kļūda izmēru maiņas attēlus vai saglabājot iestatījumus.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Your attēls (i) ir augšupielādēti.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Radās kļūda augšupielādējot savu attēlu (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fails jūs mēģināt augšupielādēt nav attēls.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fails jūs mēģināt augšupielādēt, ir pārāk liels.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Nosaukums ir saglabāts.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Vai tiešām vēlaties dzēst attēlu");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Attēls ir izdzēsts.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Radās kļūda dzēšot attēlu.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Saving parametrus un izmēru maiņas attēlus, lūdzu uzgaidiet ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Augšupielāde, lūdzu uzgaidiet ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Kārtošanas kārtība nav saglabāts. Vai vēlaties saglabāt kārtošanas secību?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Attēla kārtošanas kārtība ir saglabāts.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Radās kļūda saglabājot attēla veida.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/lv.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Pārvaldīt Lightbox gallary parametri");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "pārvaldīt galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Pilna izmēra attēlu platums");
define('MANAGE_GALLERY_FULL_HEIGHT', "Pilnā izmērā Augstums");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image platums");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image augstums");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Saglabāt Thumb malu attiecību");
define('MANAGE_GALLERY_SHOW_TITLES', "Rādīt sadaļu");
define('MANAGE_GALLERY_DISABLE_SORT', "Atslēgt Kārtot");
define('MANAGE_GALLERY_DELETE_IMAGE', "dzēst attēlu");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Saglabājiet kārtošanas secību");
define('MANAGE_GALLERY_PUBLISH_MSG', "Nospiediet &#39;Atjaunināt&#39; publicēt <br /> Jūsu augšupielādēto attēlu.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Visi attēli ir mainīti un iestatījumi ir saglabāti.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Radās kļūda izmēru maiņas attēlus vai saglabājot iestatījumus.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Your attēls (i) ir augšupielādēti.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Radās kļūda augšupielādējot savu attēlu (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fails jūs mēģināt augšupielādēt nav attēls.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fails jūs mēģināt augšupielādēt, ir pārāk liels.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Nosaukums ir saglabāts.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Vai tiešām vēlaties dzēst attēlu");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Attēls ir izdzēsts.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Radās kļūda dzēšot attēlu.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Saving parametrus un izmēru maiņas attēlus, lūdzu uzgaidiet ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Augšupielāde, lūdzu uzgaidiet ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Kārtošanas kārtība nav saglabāts. Vai vēlaties saglabāt kārtošanas secību?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Attēla kārtošanas kārtība ir saglabāts.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Radās kļūda saglabājot attēla veida.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Fails, kuru mēģināt augšupielādēt, ir lielāks par PHP iestatījumiem “upload_max_filesize” vai “post_max_size”. Sazinieties ar sistēmas administratoru, lai palielinātu šos ierobežojumus.");
?>
